@@ -37,6 +37,7 @@ def cache_to_django(
         for redis_instance_id, redis_instance_data in redis_dicts.items():
             async_tasks.append(
                 update_or_create_django_instance_from_redis_instance(
+                    redis_root,
                     redis_instance_data,
                     django_model,
                     cache_conf,
@@ -54,13 +55,15 @@ def cache_to_django(
 
             async def check_if_need_to_delete_django_instance(redis_instances_django_ids, django_instance):
                 if django_instance.id not in redis_instances_django_ids:
-                    await django_sync_to_async_list(django_instance.delete)
+                    await django_sync_to_async_delete(django_instance)
 
             all_redis_instances = redis_root.get(django_model)
             redis_instances_django_ids = []
             for redis_instance in all_redis_instances:
                 if 'django_id' in redis_instance.keys():
-                    redis_instances_django_ids.append(redis_instance['django_id'])
+                    django_id = redis_instance['django_id']
+                    if django_id not in ['null', None]:
+                        redis_instances_django_ids.append(django_id)
 
             all_django_instances = await django_sync_to_async_list(django_model.objects.all)
             async_tasks = []
@@ -91,12 +94,14 @@ def cache_to_django(
 
 
 async def update_or_create_django_instance_from_redis_instance(
+        redis_root,
         redis_instance,
         django_model,
         cache_conf,
 ):
     django_id = redis_instance['django_id']
     django_params, django_many_to_many_params = await async_redis_dict_to_django_params(
+        redis_root,
         redis_instance,
         django_model,
         cache_conf,
@@ -108,6 +113,8 @@ async def update_or_create_django_instance_from_redis_instance(
     print(new_django_params)
     django_params = new_django_params
     django_instance = await sync_to_async_update_or_create_django_instance_from_redis_instance(
+        redis_root,
+        redis_instance,
         django_id,
         django_model,
         django_params,
@@ -120,6 +127,8 @@ async def update_or_create_django_instance_from_redis_instance(
 
 @sync_to_async
 def sync_to_async_update_or_create_django_instance_from_redis_instance(
+        redis_root,
+        redis_instance,
         django_id,
         django_model,
         django_params,
@@ -141,6 +150,7 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
                 django_instance.id,
                 django_many_to_many_params
             )
+            redis_root.delete(django_model, redis_instance)
         else:
             print(f'\n'
                   f'{datetime.datetime.now()} - '
@@ -191,6 +201,7 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
 
 
 async def async_redis_dict_to_django_params(
+        redis_root,
         redis_dict,
         django_model,
         cache_conf,
@@ -208,6 +219,7 @@ async def async_redis_dict_to_django_params(
                 print(redis_foreign_key_instance)
                 if redis_foreign_key_instance not in ['null', None]:
                     django_foreign_key_instance = await update_or_create_django_instance_from_redis_instance(
+                        redis_root,
                         redis_foreign_key_instance,
                         foreign_key_model,
                         cache_conf,
@@ -223,6 +235,7 @@ async def async_redis_dict_to_django_params(
                 if redis_many_to_many_instances not in ['null', None] and redis_many_to_many_instances:
                     for redis_many_to_many_instance in redis_many_to_many_instances:
                         django_many_to_many_instance = await update_or_create_django_instance_from_redis_instance(
+                            redis_root,
                             redis_many_to_many_instance,
                             many_to_many_model,
                             cache_conf,
@@ -293,3 +306,6 @@ def django_sync_to_async_get(
     return param
 
 
+@sync_to_async
+def django_sync_to_async_delete(django_instance):
+    return django_instance.delete()
